@@ -64,6 +64,7 @@ module SiSU_DB_columns
     def initialize(md=nil)
       @md=md
       @db=SiSU_Env::Info_db.new #watch
+      @lang ||=SiSU_i18n::Languages.new
       if defined? md.opt.mod \
       and md.opt.mod.inspect=~/import|update/ \
       and FileTest.exist?(md.fns)
@@ -98,7 +99,7 @@ module SiSU_DB_columns
           'title'
         end
         def create_column
-          "#{name}                VARCHAR(#{Db[:col_title]}) NULL,"
+          "#{name}                VARCHAR(#{Db[:col_title]}) NOT NULL,"
         end
         def column_comment
           %{COMMENT ON COLUMN metadata_and_text.#{name}
@@ -120,7 +121,7 @@ module SiSU_DB_columns
           'title_main'
         end
         def create_column
-          "#{name}                VARCHAR(#{Db[:col_title_part]}) NULL,"
+          "#{name}                VARCHAR(#{Db[:col_title_part]}) NOT NULL,"
         end
         def column_comment
           %{COMMENT ON COLUMN metadata_and_text.#{name}
@@ -237,9 +238,8 @@ module SiSU_DB_columns
             IS 'metadata document language [DC12]';}
         end
         def tuple
-          t=if defined? @md.title.language \
-          and @md.title.language=~/\S+/
-            txt=@md.title.language
+          t=if @lang.list[@md.opt.lng][:n]
+            txt=@lang.list[@md.opt.lng][:n]
             special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
@@ -259,9 +259,9 @@ module SiSU_DB_columns
             IS 'metadata document language iso code';}
         end
         def tuple
-          t=if defined? @md.title.language_char \
-          and @md.title.language_char=~/\S+/
-            txt=@md.title.language_char
+          t=if defined? @md.opt.lng \
+          and @md.opt.lng=~/\S+/
+            txt=@md.opt.lng
             special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
@@ -599,9 +599,8 @@ module SiSU_DB_columns
            IS 'metadata document language';}
         end
         def tuple
-          t=if defined? @md.language.document \
-          and @md.language.document=~/\S+/
-            txt=@md.language.document
+          t=if @lang.list[@md.opt.lng][:n]
+            txt=@lang.list[@md.opt.lng][:n]
             special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
@@ -614,16 +613,17 @@ module SiSU_DB_columns
           'language_document_char'
         end
         def create_column
-          "#{name}                VARCHAR(#{Db[:col_language_char]}) NULL,"
+          "#{name}                VARCHAR(#{Db[:col_language_char]}) NOT NULL,"
         end
         def column_comment
           %{COMMENT ON COLUMN metadata_and_text.#{name}
            IS 'metadata document language';}
         end
         def tuple
-          t=if defined? @md.language.document_char \
-          and @md.language.document_char=~/\S+/
-            txt=@md.language.document_char
+          #modify check, is now required, SiSUv3d_
+          t=if defined? @md.opt.lng \
+          and @md.opt.lng=~/\S+/
+            txt=@md.opt.lng
             special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
@@ -1832,7 +1832,7 @@ module SiSU_DB_columns
           'src_filename'
         end
         def create_column
-          "#{name}                VARCHAR(#{Db[:col_filename]}) NULL,"
+          "#{name}                VARCHAR(#{Db[:col_filename]}) NOT NULL,"
         end
         def column_comment
           %{COMMENT ON COLUMN metadata_and_text.#{name}
