@@ -58,7 +58,7 @@
 =end
 module SiSU_Digest_view
   require_relative 'particulars'                        # particulars.rb
-  require_relative 'i18n'                               # i18n.rb
+  require_relative 'prog_text_translation'              # prog_text_translation.rb
   require_relative 'shared_markup_alt.rb'               # shared_markup_alt.rb
   pwd=Dir.pwd
   class Source
@@ -76,12 +76,12 @@ module SiSU_Digest_view
         @env,@md,@dal_array=@particulars.env,@particulars.md,@particulars.dal_array
         unless @opt.cmd =~/q/
           tool=(@opt.cmd =~/[MVv]/) \
-          ? "#{@env.program.text_editor} file://#{@md.file.output_path.hash_digest}/#{@md.file.base_filename.hash_digest}" \
+          ? "#{@env.program.text_editor} file://#{@md.file.output_path.hash_digest.dir}/#{@md.file.base_filename.hash_digest}" \
           : @opt.fns
           @opt.cmd=~/[MVvz]/ \
           ? SiSU_Screen::Ansi.new(@opt.cmd,"Document #{@dg} Digests",tool).green_hi_blue \
           : SiSU_Screen::Ansi.new(@opt.cmd,"Document #{@dg} Digests",tool).green_title_hi
-          SiSU_Screen::Ansi.new(@opt.cmd,@opt.fns,"file://#{@md.file.output_path.hash_digest}/#{@md.file.base_filename.hash_digest}").flow if @opt.cmd =~/[MV]/
+          SiSU_Screen::Ansi.new(@opt.cmd,@opt.fns,"file://#{@md.file.output_path.hash_digest.dir}/#{@md.file.base_filename.hash_digest}").flow if @opt.cmd =~/[MV]/
         end
         SiSU_Digest_view::Source::Scroll.new(@particulars).songsheet
         SiSU_Env::Info_skin.new(@md).select
@@ -101,8 +101,8 @@ module SiSU_Digest_view
         @@dg ||=@env.digest.type
         @@dl ||=@env.digest.length
         @dg,@dl=@@dg,@@dl
-        l=SiSU_Env::Standardise_language.new.file_to_language(@md.fns)
-        @language=l[:l]
+        l=SiSU_Env::Standardise_language.new(@md.opt.lng).language
+        @language=l[:n]
         @tr=SiSU_Translate::Source.new(@md,@language)
         @sp=' '
       end
