@@ -231,7 +231,7 @@ WOK
             and dob.ln==4
               if tracking != 0
                 Seg.new(@md).tail
-                segfilename="#{dir_epub_cont}/#{@md.fnl[:pre]}#{@@seg_name_xhtml[tracking-1]}#{@md.fnl[:mid]}#{Sfx[:epub_xhtml]}#{@md.fnl[:post]}"
+                segfilename="#{dir_epub_cont}/#{@@seg_name_xhtml[tracking-1]}#{@md.lang_code_insert}#{Sfx[:epub_xhtml]}"
                 output_epub_cont_seg=File.new(segfilename,'w') if @@seg_name_xhtml[tracking-1]
                 if dob.is=='heading' \
                 or @@seg_name_xhtml[tracking-1] !~/endnotes|book_index|metadata/
@@ -252,7 +252,7 @@ WOK
                 heading_art(dob)
                 head(dob)
                 if @@seg_name_xhtml[tracking]=='sisu_manifest' # this is for manifest, includes navigation bug
-                  segfilename="#{dir_epub_cont}/#{@md.fnl[:pre]}#{@@seg_name_xhtml[tracking]}#{@md.fnl[:mid]}#{Sfx[:epub_xhtml]}#{@md.fnl[:post]}"
+                  segfilename="#{dir_epub_cont}/#{@@seg_name_xhtml[tracking]}#{@md.lang_code_insert}#{Sfx[:epub_xhtml]}"
                   output_epub_cont_seg=File.new(segfilename,'w')
                   Seg_output.new(@md,output_epub_cont_seg,@@seg,@minitoc,'sisu_manifest').output
                   Seg.new.reinitialise #BUG navigation bug with items following metadata, and occurring before manifest, this becomes a bug ... work area for book index, FIX
