@@ -105,6 +105,7 @@ module SiSU
             @opt.fns=fns
             @opt.pth=@opt.paths[i]
             @opt.f_pth=@opt.f_pths[i]
+            @opt.lng=@opt.lngs[i]
             @@pwd=@opt.pth
             Dir.chdir(@opt.pth) #watch
             env=SiSU_Env::Info_env.new(fns)
@@ -140,7 +141,7 @@ module SiSU
 #                 when /^source_kdissert$/; SiSU_Kdi_source::Source.new(@opt).read       # -S     share_src_kdissert.rb
                   when /^digests$/;         SiSU_Digest_view::Source.new(@opt).read      # -N     digests.rb
                   when /^plaintext$/;       SiSU_Plaintext::Source.new(@opt).read        # -t -a  plaintext.rb
-#                 when /^po4a$/;            SiSU_po4a::Source.new(@opt).read             # -P     po4a.rb
+                  when /^po4a$/;            SiSU_po4a::Source.new(@opt).read             # -P     po4a.rb
                  #when /^wikispeak$/;       SiSU_Wikispeak::Source.new(@opt).read        # -g
                   when /^epub$/;            SiSU_EPUB::Source.new(@opt).read             # -e     epub.rb
                   when /^odf$/;             SiSU_ODF::Source.new(@opt).read              # -o     odf.rb
@@ -152,7 +153,7 @@ module SiSU
                   when /^xhtml$/;           SiSU_XHTML::Source.new(@opt).read            # -b     xhtml.rb
                   when /^xml$/;             SiSU_XML_SAX::Source.new(@opt).read          # -x     xml.rb
                   when /^xml_dom$/;         SiSU_XML_DOM::Source.new(@opt).read          # -X     xml_dom.rb
-                  when /^xml_fictionbook$/; SiSU_XML_Fictionbook::Source.new(@opt).read  # -f
+                 #when /^xml_fictionbook$/; SiSU_XML_Fictionbook::Source.new(@opt).read  # -f
                   when /^xml_scaffold$/;    SiSU_XML_scaffold::Source.new(@opt).read     # -k     xml_scaffold.rb
                   when /^embedded$/;        SiSU_Embedded::Source.new(@opt).read         # -m     embedded.rb (image and other content) #check
                   when /^manifest$/;        SiSU_Manifest::Source.new(@opt).read         # -y     manifest.rb
@@ -419,9 +420,9 @@ p "here #{__FILE__} #{__LINE__}" if @opt =~/M/
         if @opt.act[:xml_dom]                              #% --xml-dom, -x xml dom type
           op('xml_dom','xml dom')
         end
-        if @opt.act[:fictionbook]                          #% --fictionbook, -f fictionbook xml
-          op('xml_fictionbook','xml fictionbook')
-        end
+       #if @opt.act[:fictionbook]                          #% --fictionbook, -f fictionbook xml
+       #  op('xml_fictionbook','xml fictionbook')
+       #end
         if @opt.act[:xhtml]                                #% --xhtml, -b xhtml
           op('xhtml','xhtml sax')
         end
