@@ -106,8 +106,8 @@ module SiSU_TeX
         SiSU_Screen::Ansi.new(@opt.cmd,'LaTeX/PDF',@md.fns).green_title_hi unless @opt.cmd =~/q/
         if @opt.cmd =~/[MVv]/
           path=@env.url.output_tell
-          SiSU_Screen::Ansi.new(@opt.cmd,@opt.fns,"#{@env.program.pdf_viewer} #{@md.file.output_path.pdf}/#{@md.file.base_filename.pdf_l}pdf").flow
-          SiSU_Screen::Ansi.new(@opt.cmd,@opt.fns,"#{@env.program.pdf_viewer} #{@md.file.output_path.pdf}/#{@md.file.base_filename.pdf_p}pdf").flow
+          SiSU_Screen::Ansi.new(@opt.cmd,@opt.fns,"#{@env.program.pdf_viewer} #{@md.file.output_path.pdf.dir}/#{@md.file.base_filename.pdf_l}pdf").flow
+          SiSU_Screen::Ansi.new(@opt.cmd,@opt.fns,"#{@env.program.pdf_viewer} #{@md.file.output_path.pdf.dir}/#{@md.file.base_filename.pdf_p}pdf").flow
         end
         @md=@particulars.md
         $flag=@md.opt.cmd                                                          #introduced to pass 0 for no object citation numbers... to texpdf_format
@@ -149,6 +149,7 @@ module SiSU_TeX
       @@n_lpdf||=0 #change
       def initialize(md,env)
         @md,@env=md,env
+        @f=SiSU_Env::SiSU_file.new(@md).base_filename
       end
       def latex_do(texfilename,papersize)
         @texfilename=texfilename
@@ -175,21 +176,21 @@ module SiSU_TeX
         portrait_pdf="#{pwd}/#{tex_fn_base}.pdf"
         landscape_pdf="#{pwd}/#{tex_fn_base}.landscape.pdf"
         case papersize
-        when /a4/;     pdf_p=@md.file.base_filename.pdf_p_a4;     pdf_l=@md.file.base_filename.pdf_l_a4
-        when /a5/;     pdf_p=@md.file.base_filename.pdf_p_a5;     pdf_l=@md.file.base_filename.pdf_l_a5
-        when /b5/;     pdf_p=@md.file.base_filename.pdf_p_b5;     pdf_l=@md.file.base_filename.pdf_l_b5
-        when /letter/; pdf_p=@md.file.base_filename.pdf_p_letter; pdf_l=@md.file.base_filename.pdf_l_letter
-        when /legal/;  pdf_p=@md.file.base_filename.pdf_p_legal;  pdf_l=@md.file.base_filename.pdf_l_legal
-        else           pdf_p=@md.file.base_filename.pdf_p_a4;     pdf_l=@md.file.base_filename.pdf_l_a4
+        when /a4/;     pdf_p=@f.pdf_p_a4;     pdf_l=@f.pdf_l_a4
+        when /a5/;     pdf_p=@f.pdf_p_a5;     pdf_l=@f.pdf_l_a5
+        when /b5/;     pdf_p=@f.pdf_p_b5;     pdf_l=@f.pdf_l_b5
+        when /letter/; pdf_p=@f.pdf_p_letter; pdf_l=@f.pdf_l_letter
+        when /legal/;  pdf_p=@f.pdf_p_legal;  pdf_l=@f.pdf_l_legal
+        else           pdf_p=@f.pdf_p_a4;     pdf_l=@f.pdf_l_a4
         end
-        Dir.mkdir(@md.file.output_path.pdf) unless FileTest.directory?(@md.file.output_path.pdf)
+        Dir.mkdir(@md.file.output_path.pdf.dir) unless FileTest.directory?(@md.file.output_path.pdf.dir)
         if FileTest.file?(portrait_pdf)
-          cp(portrait_pdf,"#{@md.file.output_path.pdf}/#{pdf_p}")
+          cp(portrait_pdf,"#{@md.file.output_path.pdf.dir}/#{pdf_p}")
           rm(portrait_pdf)
         else p "#{__FILE__}:#{__LINE__} NOT FOUND: #{portrait_pdf}" if @md.opt.cmd.inspect =~/M/
         end
         if FileTest.file?(landscape_pdf)
-          cp(landscape_pdf,"#{@md.file.output_path.pdf}/#{pdf_l}")
+          cp(landscape_pdf,"#{@md.file.output_path.pdf.dir}/#{pdf_l}")
           rm(landscape_pdf)
         else p "#{__FILE__}:#{__LINE__} NOT FOUND: #{landscape_pdf}" if @md.opt.cmd.inspect =~/M/
         end
@@ -223,33 +224,33 @@ module SiSU_TeX
               end
             end
             case @md.papersize_array[0] #default pdf
-            when /a4/;     pdf_p=@md.file.base_filename.pdf_p_a4;     pdf_l=@md.file.base_filename.pdf_l_a4
-            when /a5/;     pdf_p=@md.file.base_filename.pdf_p_a5;     pdf_l=@md.file.base_filename.pdf_l_a5
-            when /b5/;     pdf_p=@md.file.base_filename.pdf_p_b5;     pdf_l=@md.file.base_filename.pdf_l_b5
-            when /letter/; pdf_p=@md.file.base_filename.pdf_p_letter; pdf_l=@md.file.base_filename.pdf_l_letter
-            when /legal/;  pdf_p=@md.file.base_filename.pdf_p_legal;  pdf_l=@md.file.base_filename.pdf_l_legal
-            else           pdf_p=@md.file.base_filename.pdf_p_a4;     pdf_l=@md.file.base_filename.pdf_l_a4
+            when /a4/;     pdf_p=@f.pdf_p_a4;     pdf_l=@f.pdf_l_a4
+            when /a5/;     pdf_p=@f.pdf_p_a5;     pdf_l=@f.pdf_l_a5
+            when /b5/;     pdf_p=@f.pdf_p_b5;     pdf_l=@f.pdf_l_b5
+            when /letter/; pdf_p=@f.pdf_p_letter; pdf_l=@f.pdf_l_letter
+            when /legal/;  pdf_p=@f.pdf_p_legal;  pdf_l=@f.pdf_l_legal
+            else           pdf_p=@f.pdf_p_a4;     pdf_l=@f.pdf_l_a4
             end
-            if FileTest.file?("#{@md.file.output_path.pdf}/#{pdf_p}")
+            if FileTest.file?("#{@md.file.output_path.pdf.dir}/#{pdf_p}")
               mklnk=if @md.file.output_dir_structure.by_language_code? \
               or @md.file.output_dir_structure.by_filetype?
                 "#{@md.fnb}.portrait.pdf"
               else 'portrait.pdf'
               end
               system("
-                cd #{@md.file.output_path.pdf}
+                cd #{@md.file.output_path.pdf.dir}
                 rm #{mklnk}
                 ln -s #{pdf_p} #{mklnk}
               ")
             end
-            if FileTest.file?("#{@md.file.output_path.pdf}/#{pdf_l}")
+            if FileTest.file?("#{@md.file.output_path.pdf.dir}/#{pdf_l}")
               mklnk=if @md.file.output_dir_structure.by_language_code? \
               or @md.file.output_dir_structure.by_filetype?
                 "#{@md.fnb}.landscape.pdf"
               else 'landscape.pdf'
               end
               system("
-                cd #{@md.file.output_path.pdf}
+                cd #{@md.file.output_path.pdf.dir}
                 rm #{mklnk}
                 ln -s #{pdf_l} #{mklnk}
               ")
