@@ -614,7 +614,7 @@ module SiSU_TeX_Pdf
     end
   end
   class Format_head
-    require_relative 'i18n'                         # defaults.rb
+    require_relative 'prog_text_translation'        # prog_text_translation.rb
     def initialize(md,t_o)
       @md,@t_o=md,t_o
       @env=SiSU_Env::Info_env.new(@md.fns)
@@ -632,14 +632,14 @@ module SiSU_TeX_Pdf
       @brace_url=SiSU_Viz::Skin.new.url_decoration
       @tex2pdf=@@tex3pdf ||=SiSU_Env::System_call.new.tex2pdf_engine
       @ps=@txt if @txt=~/(?:a4|letter|legal|book|a5|b5)/i
-      @lang ||=SiSU_i18n::Language.new(@md)
+      @lang ||=SiSU_i18n::Languages.new #.list[@md.opt.lng][:xlp]
     end
     def tex_head_lang #babel 18n
       lang_char_arr=@md.i18n
       mainlang_char=lang_char_arr.slice(0)
-      mainlang=@lang.tex_name(mainlang_char)
+      mainlang=@lang.list[mainlang_char][:xlp]
       otherlang=[]
-      lang_char_arr.slice(1..9).each { |ch| otherlang << @lang.tex_name(ch) }
+      lang_char_arr.slice(1..9).each { |ch| otherlang << @lang.list[ch][:xlp] }
       otherlang=otherlang.join(',')
       { mainlang: mainlang, otherlang: otherlang }
     end
@@ -893,7 +893,7 @@ WOK
     end
     def document_head_with_orientation
       endnotes=("\\usepackage{endnotes}" if @txt =~/endnotes?/)||'' #not implemented see also def endnotes
-      @lang.tex_name(@md.i18n[0])
+      @lang.list[@md.i18n[0]][:xlp]
       <<WOK
 #{tex_head_paper}
 #{tex_head_encode}
@@ -956,7 +956,7 @@ WOK
   {-\\baselineskip}{0.5\\baselineskip}%
   {\\normalfont\\normalsize\\itshape\\raggedright}}
 % \\makeatother
-\\selectlanguage{#{@lang.tex_name(@md.i18n[0])}}
+\\selectlanguage{#{@lang.list[@md.i18n[0]][:xlp]}}
 WOK
     end
     def a4generic
